@@ -50,7 +50,7 @@ except ImportError:
     Launchpad = None
 
 SYNAPTIC_PINFILE = "/var/lib/synaptic/preferences"
-CHANGELOGS_POOL = "http://changelogs.ubuntu.com/changelogs/pool/"
+CHANGELOGS_POOL = "https://changelogs.ubuntu.com/changelogs/pool/"
 CHANGELOGS_URI = CHANGELOGS_POOL + "%s/%s/%s/%s_%s/%s"
 
 
