@@ -16,7 +16,7 @@ class HelpViewer:
         self.docu = docu
         for viewer in KNOWN_VIEWERS:
             if os.path.exists(viewer):
-                self.command = [viewer, "ghelp:%s" % docu]
+                self.command = [viewer, "help:%s" % docu]
                 break
 
     def check(self):
