@@ -26,7 +26,6 @@ from gi.repository import Gtk
 from gi.repository import Gdk, GdkX11
 from gi.repository import Gio
 from gi.repository import GLib
-from gi.repository import GObject
 
 GdkX11  # pyflakes
 
@@ -95,9 +94,7 @@ class UpdateManager(Gtk.Window):
 
         # Keep window at a constant size
         ctx = self.get_style_context()
-        self.style_changed = ctx.connect("changed",
-                                         lambda ctx:
-                                             self.resize_to_standard_width())
+        ctx.connect("changed", lambda ctx: self.resize_to_standard_width())
 
         # Signals
         self.connect("delete-event", self._on_close)
@@ -138,11 +135,9 @@ class UpdateManager(Gtk.Window):
         if dpi <= 0:
             dpi = 96
         ctx = self.get_style_context()
-        GObject.signal_handler_block(ctx, self.style_changed)
         size = ctx.get_property("font-size", Gtk.StateFlags.NORMAL)
         width = dpi / 72 * size * num_em
         self.set_size_request(width, -1)
-        GObject.signal_handler_unblock(ctx, self.style_changed)
 
     def on_initial_focus_in(self, widget, event):
         """callback run on initial focus-in (if started unmapped)"""
