@@ -282,7 +282,7 @@ class UpdatesAvailable(InternalDialog):
         self.pkg_cell_area = CellAreaPackage(False)
         pkg_column = Gtk.TreeViewColumn.new_with_area(self.pkg_cell_area)
         self.pkg_cell_area.column = pkg_column
-        pkg_column.set_title(_("Install"))
+        pkg_column.set_title(_("Install or remove"))
         pkg_column.set_property("spacing", 4)
         pkg_column.set_expand(True)
         self.treeview_update.append_column(pkg_column)
@@ -823,25 +823,56 @@ class UpdatesAvailable(InternalDialog):
 
     def on_button_install_clicked(self):
         self.unity.set_install_menuitem_visible(False)
-        #print("on_button_install_clicked")
+        # print("on_button_install_clicked")
         err_sum = _("Not enough free disk space")
-        err_long = _("The upgrade needs a total of %s free space on "
-                     "disk '%s'. "
-                     "Please free at least an additional %s of disk "
-                     "space on '%s'. "
-                     "Empty your trash and remove temporary "
-                     "packages of former installations using "
-                     "'sudo apt-get clean'.")
+        err_msg = _("The upgrade needs a total of %s free space on "
+                    "disk '%s'. "
+                    "Please free at least an additional %s of disk "
+                    "space on '%s'. %s")
+        # specific ways to resolve lack of free space
+        remedy_archivedir = _("Remove temporary packages of former "
+                              "installations using 'sudo apt clean'.")
+        remedy_boot = _("You can remove old kernels using "
+                        "'sudo apt autoremove', and you could also "
+                        "set COMPRESS=xz in "
+                        "/etc/initramfs-tools/initramfs.conf to "
+                        "reduce the size of your initramfs.")
+        remedy_root = _("Empty your trash and remove temporary "
+                        "packages of former installations using "
+                        "'sudo apt clean'.")
+        remedy_tmp = _("Reboot to clean up files in /tmp.")
+        remedy_usr = _("")
         # check free space and error if its not enough
         try:
             self.cache.checkFreeSpace()
         except NotEnoughFreeSpaceError as e:
+            # CheckFreeSpace examines where packages are cached
+            archivedir = apt_pkg.config.find_dir("Dir::Cache::archives")
+            err_long = ""
             for req in e.free_space_required_list:
-                self.window_main.start_error(False, err_sum,
-                                             err_long % (req.size_total,
-                                                         req.dir,
-                                                         req.size_needed,
-                                                         req.dir))
+                if err_long != "":
+                    err_long += " "
+                if req.dir == archivedir:
+                    err_long += err_msg % (req.size_total, req.dir,
+                                           req.size_needed, req.dir,
+                                           remedy_archivedir)
+                elif req.dir == "/boot":
+                    err_long += err_msg % (req.size_total, req.dir,
+                                           req.size_needed, req.dir,
+                                           remedy_boot)
+                elif req.dir == "/":
+                    err_long += err_msg % (req.size_total, req.dir,
+                                           req.size_needed, req.dir,
+                                           remedy_root)
+                elif req.dir == "/tmp":
+                    err_long += err_msg % (req.size_total, req.dir,
+                                           req.size_needed, req.dir,
+                                           remedy_tmp)
+                elif req.dir == "/usr":
+                    err_long += err_msg % (req.size_total, req.dir,
+                                           req.size_needed, req.dir,
+                                           remedy_usr)
+            self.window_main.start_error(False, err_sum, err_long)
             return
         except SystemError as e:
             logging.exception("free space check failed")
@@ -924,7 +955,10 @@ class UpdatesAvailable(InternalDialog):
                 if keep_packages:
                     item.pkg.mark_keep()
                 elif item.pkg.name not in self.list.held_back:
-                    item.pkg.mark_install()
+                    if not item.to_remove:
+                        item.pkg.mark_install()
+                    else:
+                        item.pkg.mark_delete()
             except SystemError:
                 pass
 
@@ -1020,11 +1054,20 @@ class UpdatesAvailable(InternalDialog):
             self._add_groups(self.list.security_groups)
         if self.list.security_groups and self.list.update_groups:
             self._add_header(_("Other updates"), self.list.update_groups)
+        elif self.list.update_groups and self.list.kernel_autoremove_groups:
+            self._add_header(_("Updates"), self.list.update_groups)
         if self.list.update_groups:
             self._add_groups(self.list.update_groups)
+        if self.list.kernel_autoremove_groups:
+            self._add_header(
+                _("Unused kernel updates to be removed"),
+                self.list.kernel_autoremove_groups)
+            self._add_groups(self.list.kernel_autoremove_groups)
 
         self.treeview_update.set_model(self.store)
-        self.pkg_cell_area.indent_toplevel = bool(self.list.security_groups)
+        self.pkg_cell_area.indent_toplevel = (
+            bool(self.list.security_groups) or
+            bool(self.list.kernel_autoremove_groups))
         self.update_close_button()
         self.update_count()
         self.setBusy(False)
