@@ -1,9 +1,8 @@
+#!/usr/bin/python3
 
-#!/usr/bin/python
-
-from __future__ import print_function
 
 import apt
+import builtins
 import unittest
 import os
 
@@ -14,6 +13,8 @@ from mock import (
 
 import hwe_support_status
 
+builtins  # pyflakes
+
 
 def make_mock_pkg(name, ver_str="1.0"):
     arch = apt.apt_pkg.config.find("APT::Architecture")
@@ -73,7 +74,7 @@ class HweSupportStatusTestCase(TestCase):
 
     def test_advice_about_hwe_status_is_running(self):
         with patch("hwe_support_status.is_unsupported_hwe_running") as m:
-            with patch("__builtin__.print") as mock_print:
+            with patch("builtins.print") as mock_print:
                 m.return_value = True
                 mock_unsupported_hwe_pkgs = []
                 mock_unsupported_hwe_pkgs.append(make_mock_pkg(
@@ -82,14 +83,15 @@ class HweSupportStatusTestCase(TestCase):
                 from datetime import timedelta
                 today = HWE_EOL_DATE - timedelta(14)
                 hwe_support_status.advice_about_hwe_status(
-                    mock_unsupported_hwe_pkgs, [], [], False, today, verbose=True)
+                    mock_unsupported_hwe_pkgs, [], [], False, today,
+                    verbose=True)
                 text = mock_print.call_args[0][0]
                 self.assertIn("Your current Hardware Enablement Stack (HWE) "
                               "is going out of support", text)
 
     def test_advice_about_hwe_status_installed_only(self):
         with patch("hwe_support_status.is_unsupported_hwe_running") as m:
-            with patch("__builtin__.print") as mock_print:
+            with patch("builtins.print") as mock_print:
                 m.return_value = False
                 mock_unsupported_hwe_pkgs = []
                 mock_unsupported_hwe_pkgs.append(make_mock_pkg(
@@ -98,21 +100,24 @@ class HweSupportStatusTestCase(TestCase):
                 from datetime import timedelta
                 today = HWE_EOL_DATE + timedelta(14)
                 hwe_support_status.advice_about_hwe_status(
-                    mock_unsupported_hwe_pkgs, [], [], False, today, verbose=True)
+                    mock_unsupported_hwe_pkgs, [], [], False, today,
+                    verbose=True)
                 text = mock_print.call_args[0][0]
-                self.assertIn("You have packages from the Hardware Enablement "
-                              "Stack (HWE) installed that", text)
+                self.assertIn("You have packages from the Hardware "
+                              "Enablement Stack (HWE) installed that",
+                              text)
 
     def test_advice_about_hwe_status_no_hwe_stack(self):
         with patch("hwe_support_status.is_unsupported_hwe_running") as m:
-            with patch("__builtin__.print") as mock_print:
+            with patch("builtins.print") as mock_print:
                 m.return_value = False
                 mock_unsupported_hwe_pkgs = []
                 from HweSupportStatus.consts import LTS_EOL_DATE
                 from datetime import timedelta
                 today = LTS_EOL_DATE - timedelta(14)
                 hwe_support_status.advice_about_hwe_status(
-                    mock_unsupported_hwe_pkgs, [], [], False, today, verbose=True)
+                    mock_unsupported_hwe_pkgs, [], [], False, today,
+                    verbose=True)
                 text = mock_print.call_args[0][0]
                 print("43242343243", mock_print.call_count)
                 self.assertIn(
@@ -120,7 +125,7 @@ class HweSupportStatusTestCase(TestCase):
 
     def test_advice_about_hwe_status_supported_hwe_stack(self):
         with patch("hwe_support_status.is_unsupported_hwe_running") as m:
-            with patch("__builtin__.print") as mock_print:
+            with patch("builtins.print") as mock_print:
                 m.return_value = False
                 mock_supported_hwe_pkgs = []
                 mock_supported_hwe_pkgs.append(make_mock_pkg(
@@ -129,7 +134,8 @@ class HweSupportStatusTestCase(TestCase):
                 from datetime import timedelta
                 today = LTS_EOL_DATE - timedelta(14)
                 hwe_support_status.advice_about_hwe_status(
-                    [], mock_supported_hwe_pkgs, [], False, today, verbose=True)
+                    [], mock_supported_hwe_pkgs, [], False, today,
+                    verbose=True)
                 text = mock_print.call_args[0][0]
                 self.assertIn(
                     "Your Hardware Enablement Stack (HWE) is supported "
